@@ -29,30 +29,17 @@ function download_kafka {
     url="https://github.com/knative-sandbox/eventing-kafka/releases/download/$version/$file"
 
     wget --no-check-certificate "$url" -O "$target_file"
+
+    # Break all image references so we know our overrides work correctly.
+    yaml.break_image_references "$target_file"
   done
 }
 
-
-version=${KOURIER_VERSION:-v$(metadata.get dependencies.kourier)}
-
-target_dir="$root/knative-operator/deploy/resources/kourier"
-rm -rf "$target_dir"
-mkdir -p "$target_dir"
-
-target_file="$target_dir/kourier-latest.yaml"
-
-url="https://github.com/knative-sandbox/net-kourier/releases/download/$version/kourier.yaml"
-wget --no-check-certificate "$url" -O "$target_file"
-
-# TODO: [SRVKS-610] These values should be replaced by operator instead of sed.
-sed -i -e 's/kourier-control.knative-serving/kourier-control.knative-serving-ingress/g' "$target_file"
-
 download_kafka knativekafka "$KNATIVE_EVENTING_KAFKA_VERSION" "${kafka_files[@]}"
-# For Backport of v1alpha1 hacks, we change the storage versions:
-git apply "$root/knative-operator/hack/006-kafkachannel-storage-beta1.patch"
 
-# This is for  SRVKe-807.
+# SRVKE-884: for 1.16 we remove the HPA
+git apply "$root/knative-operator/hack/001-eventing-kafka-hpa.patch"
+
+# Change the minavailable pdb for kafka-webhook to 1
 git apply "$root/knative-operator/hack/007-eventing-kafka-pdb.patch"
-
-# This is for SRVKE-814
-git apply "$root/knative-operator/hack/008-eventing-kafka-hpa.patch"
+git apply "$root/knative-operator/hack/008-eventing-kafka-webhook-resources.patch"
