@@ -38,6 +38,7 @@ var (
 	role              = mf.Any(mf.ByKind("ClusterRole"), mf.ByKind("Role"))
 	rolebinding       = mf.Any(mf.ByKind("ClusterRoleBinding"), mf.ByKind("RoleBinding"))
 	roleOrRoleBinding = mf.Any(role, rolebinding)
+	KafkaHAComponents = []string{"kafka-ch-controller", "kafka-webhook", "kafka-controller-manager"}
 )
 
 type stage func(*mf.Manifest, *operatorv1alpha1.KnativeKafka) error
@@ -59,22 +60,16 @@ func newReconciler(mgr manager.Manager) (*ReconcileKnativeKafka, error) {
 		return nil, fmt.Errorf("failed to load KafkaChannel manifest: %w", err)
 	}
 
-	kafkaChannelPostInstallManifest, err := mf.ManifestFrom(mf.Path(os.Getenv("KAFKACHANNEL_POST_INSTALL_MANIFEST_PATH")))
-	if err != nil {
-		return nil, fmt.Errorf("failed to load KafkaChannel Post Install manifest: %w", err)
-	}
-
 	kafkaSourceManifest, err := mf.ManifestFrom(mf.Path(os.Getenv("KAFKASOURCE_MANIFEST_PATH")))
 	if err != nil {
 		return nil, fmt.Errorf("failed to load KafkaSource manifest: %w", err)
 	}
 
 	reconcileKnativeKafka := ReconcileKnativeKafka{
-		client:                             mgr.GetClient(),
-		scheme:                             mgr.GetScheme(),
-		rawKafkaChannelManifest:            kafkaChannelManifest,
-		rawKafkaChannelPostInstallManifest: kafkaChannelPostInstallManifest,
-		rawKafkaSourceManifest:             kafkaSourceManifest,
+		client:                  mgr.GetClient(),
+		scheme:                  mgr.GetScheme(),
+		rawKafkaChannelManifest: kafkaChannelManifest,
+		rawKafkaSourceManifest:  kafkaSourceManifest,
 	}
 	return &reconcileKnativeKafka, nil
 }
@@ -112,11 +107,10 @@ var _ reconcile.Reconciler = &ReconcileKnativeKafka{}
 type ReconcileKnativeKafka struct {
 	// This client, initialized using mgr.Client() above, is a split client
 	// that reads objects from the cache and writes to the apiserver
-	client                             client.Client
-	scheme                             *runtime.Scheme
-	rawKafkaChannelManifest            mf.Manifest
-	rawKafkaChannelPostInstallManifest mf.Manifest
-	rawKafkaSourceManifest             mf.Manifest
+	client                  client.Client
+	scheme                  *runtime.Scheme
+	rawKafkaChannelManifest mf.Manifest
+	rawKafkaSourceManifest  mf.Manifest
 }
 
 // Reconcile reads that state of the cluster for a KnativeKafka object and makes changes based on the state read
@@ -170,10 +164,7 @@ func (r *ReconcileKnativeKafka) reconcileKnativeKafka(instance *operatorv1alpha1
 		return err
 	}
 	// delete the components that are disabled
-	if err := r.executeDeleteStages(instance); err != nil {
-		return err
-	}
-	return nil
+	return r.executeDeleteStages(instance)
 }
 
 func (r *ReconcileKnativeKafka) executeInstallStages(instance *operatorv1alpha1.KnativeKafka) error {
@@ -183,6 +174,7 @@ func (r *ReconcileKnativeKafka) executeInstallStages(instance *operatorv1alpha1.
 	}
 
 	stages := []stage{
+		r.configure,
 		r.ensureFinalizers,
 		r.transform,
 		r.apply,
@@ -206,6 +198,22 @@ func (r *ReconcileKnativeKafka) executeDeleteStages(instance *operatorv1alpha1.K
 	return executeStages(instance, manifest, stages)
 }
 
+// set defaults for Openshift
+func (r *ReconcileKnativeKafka) configure(manifest *mf.Manifest, instance *operatorv1alpha1.KnativeKafka) error {
+	before := instance.DeepCopy()
+	common.MutateKafka(instance)
+	if equality.Semantic.DeepEqual(before.Spec, instance.Spec) {
+		return nil
+	}
+
+	// Only apply the update if something changed.
+	log.Info("Updating KnativeKafka with mutated state for Openshift")
+	if err := r.client.Update(context.TODO(), instance); err != nil {
+		return fmt.Errorf("failed to update KnativeKafka with mutated state: %w", err)
+	}
+	return nil
+}
+
 // set a finalizer to clean up cluster-scoped resources and resources from other namespaces
 func (r *ReconcileKnativeKafka) ensureFinalizers(_ *mf.Manifest, instance *operatorv1alpha1.KnativeKafka) error {
 	for _, finalizer := range instance.GetFinalizers() {
@@ -220,16 +228,22 @@ func (r *ReconcileKnativeKafka) ensureFinalizers(_ *mf.Manifest, instance *opera
 
 func (r *ReconcileKnativeKafka) transform(manifest *mf.Manifest, instance *operatorv1alpha1.KnativeKafka) error {
 	log.Info("Transforming manifest")
+	rbacProxyTranform, err := getRBACProxyInjectTransformer(r.client)
+	if err != nil {
+		return err
+	}
 	m, err := manifest.Transform(
 		mf.InjectOwner(instance),
 		common.SetAnnotations(map[string]string{
 			common.KafkaOwnerName:      instance.Name,
 			common.KafkaOwnerNamespace: instance.Namespace,
 		}),
+		setKafkaDeployments(instance.Spec.HighAvailability.Replicas),
 		setBootstrapServers(instance.Spec.Channel.BootstrapServers),
 		setAuthSecret(instance.Spec.Channel.AuthSecretNamespace, instance.Spec.Channel.AuthSecretName),
 		ImageTransform(common.BuildImageOverrideMapFromEnviron(os.Environ(), "KAFKA_IMAGE_"), log),
 		replicasTransform(manifest.Client),
+		rbacProxyTranform,
 	)
 	if err != nil {
 		return fmt.Errorf("failed to transform manifest: %w", err)
@@ -369,11 +383,20 @@ func (r *ReconcileKnativeKafka) buildManifest(instance *operatorv1alpha1.Knative
 	var resources []unstructured.Unstructured
 
 	if build == manifestBuildAll || (build == manifestBuildEnabledOnly && instance.Spec.Channel.Enabled) || (build == manifestBuildDisabledOnly && !instance.Spec.Channel.Enabled) {
+		channelRBACProxy, err := addRBACProxySupportToManifest(instance, kafkaChannelComponents)
+		if err != nil {
+			return nil, err
+		}
+		resources = append(resources, channelRBACProxy.Resources()...)
 		resources = append(resources, r.rawKafkaChannelManifest.Resources()...)
-		resources = append(resources, r.rawKafkaChannelPostInstallManifest.Resources()...)
 	}
 
 	if build == manifestBuildAll || (build == manifestBuildEnabledOnly && instance.Spec.Source.Enabled) || (build == manifestBuildDisabledOnly && !instance.Spec.Source.Enabled) {
+		sourceRBACProxy, err := addRBACProxySupportToManifest(instance, kafkaSourceComponents)
+		if err != nil {
+			return nil, err
+		}
+		resources = append(resources, sourceRBACProxy.Resources()...)
 		resources = append(resources, r.rawKafkaSourceManifest.Resources()...)
 	}
 
@@ -416,6 +439,27 @@ func setAuthSecret(secretNamespace, secretName string) mf.Transformer {
 	}
 }
 
+func checkHAComponent(name string) bool {
+	for _, component := range KafkaHAComponents {
+		if name == component {
+			return true
+		}
+	}
+	return false
+}
+
+func setKafkaDeployments(replicas int32) mf.Transformer {
+	return func(u *unstructured.Unstructured) error {
+		if u.GetKind() == "Deployment" && checkHAComponent(u.GetName()) {
+			log.Info("Setting Kafka HA component", "deployment", u.GetName(), "replicas", replicas)
+			if err := unstructured.SetNestedField(u.Object, int64(replicas), "spec", "replicas"); err != nil {
+				return err
+			}
+		}
+		return nil
+	}
+}
+
 func executeStages(instance *operatorv1alpha1.KnativeKafka, manifest *mf.Manifest, stages []stage) error {
 	// Execute each stage in sequence until one returns an error
 	for _, stage := range stages {
