@@ -10,6 +10,8 @@ import (
 	"github.com/openshift-knative/serverless-operator/openshift-knative-operator/pkg/monitoring"
 	"github.com/openshift-knative/serverless-operator/pkg/client/clientset/versioned"
 	ocpclient "github.com/openshift-knative/serverless-operator/pkg/client/injection/client"
+	corev1 "k8s.io/api/core/v1"
+	apierrors "k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/client-go/kubernetes"
@@ -22,6 +24,8 @@ import (
 const (
 	loggingURLTemplate = "https://%s/app/kibana#/discover?_a=(index:.all,query:'kubernetes.labels.serving_knative_dev%%5C%%2FrevisionUID:${REVISION_UID}')"
 	requiredNsEnvName  = "REQUIRED_SERVING_NAMESPACE"
+
+	defaultDomainTemplate = "{{.Name}}-{{.Namespace}}.{{.Domain}}"
 )
 
 // NewExtension creates a new extension for a Knative Serving controller.
@@ -38,19 +42,18 @@ type extension struct {
 }
 
 func (e *extension) Manifests(ks v1alpha1.KComponent) ([]mf.Manifest, error) {
-	return monitoring.LoadServingMonitoringPlatformManifests(ks.GetNamespace())
+	return monitoring.GetServingMonitoringPlatformManifests(ks)
 }
 
 func (e *extension) Transformers(ks v1alpha1.KComponent) []mf.Transformer {
-	return []mf.Transformer{
-		monitoring.InjectNamespaceWithSubject(ks.GetNamespace(), monitoring.OpenshiftMonitoringNamespace),
-		monitoring.InjectRbacProxyContainerToDeployments(),
-		common.InjectEnvironmentIntoDeployment("controller", "controller", map[string]string{
-			"HTTP_PROXY":  os.Getenv("HTTP_PROXY"),
-			"HTTPS_PROXY": os.Getenv("HTTPS_PROXY"),
-			"NO_PROXY":    os.Getenv("NO_PROXY"),
-		}),
-	}
+	return append([]mf.Transformer{
+		common.InjectEnvironmentIntoDeployment("controller", "controller",
+			corev1.EnvVar{Name: "HTTP_PROXY", Value: os.Getenv("HTTP_PROXY")},
+			corev1.EnvVar{Name: "HTTPS_PROXY", Value: os.Getenv("HTTPS_PROXY")},
+			corev1.EnvVar{Name: "NO_PROXY", Value: os.Getenv("NO_PROXY")},
+		),
+		overrideKourierNamespace(kourierNamespace(ks.GetNamespace())),
+	}, monitoring.GetServingTransformers(ks)...)
 }
 
 func (e *extension) Reconcile(ctx context.Context, comp v1alpha1.KComponent) error {
@@ -63,9 +66,9 @@ func (e *extension) Reconcile(ctx context.Context, comp v1alpha1.KComponent) err
 		return controller.NewPermanentError(fmt.Errorf("deployed Knative Serving into unsupported namespace %q", ks.Namespace))
 	}
 
-	// Mark the Kourier dependency as installing to avoid race conditions with readiness.
-	if ks.Status.GetCondition(v1alpha1.DependenciesInstalled).IsUnknown() {
-		ks.Status.MarkDependencyInstalling("Kourier")
+	// Mark failed dependencies as succeeded since we're no longer using that mechanism anyway.
+	if ks.Status.GetCondition(v1alpha1.DependenciesInstalled).IsFalse() {
+		ks.Status.MarkDependenciesInstalled()
 	}
 
 	// Set the default host to the cluster's host.
@@ -84,7 +87,7 @@ func (e *extension) Reconcile(ctx context.Context, comp v1alpha1.KComponent) err
 	// Override images.
 	// TODO(SRVCOM-1069): Rethink overriding behavior and/or error surfacing.
 	images := common.ImageMapFromEnvironment(os.Environ())
-	ks.Spec.Registry.Override = common.ImageMapFromEnvironment(os.Environ())
+	ks.Spec.Registry.Override = images
 	ks.Spec.Registry.Default = images["default"]
 	common.Configure(&ks.Spec.CommonSpec, "deployment", "queueSidecarImage", images["queue-proxy"])
 
@@ -95,13 +98,12 @@ func (e *extension) Reconcile(ctx context.Context, comp v1alpha1.KComponent) err
 		}
 	}
 
-	// Use Kourier.
-	// TODO(SRVCOM-1069): Rethink overriding behavior and/or error surfacing.
-	common.Configure(&ks.Spec.CommonSpec, "network", "ingress.class", "kourier.ingress.networking.knative.dev")
+	// Apply an Ingress config with Kourier enabled if nothing else is defined.
+	defaultToKourier(ks)
+	common.ConfigureIfUnset(&ks.Spec.CommonSpec, "network", "ingress.class", defaultIngressClass(ks))
 
 	// Override the default domainTemplate to use $name-$ns rather than $name.$ns.
-	// TODO(SRVCOM-1069): Rethink overriding behavior and/or error surfacing.
-	common.Configure(&ks.Spec.CommonSpec, "network", "domainTemplate", "{{.Name}}-{{.Namespace}}.{{.Domain}}")
+	common.ConfigureIfUnset(&ks.Spec.CommonSpec, "network", "domainTemplate", defaultDomainTemplate)
 
 	// Ensure webhook has 1G of memory.
 	common.EnsureContainerMemoryLimit(&ks.Spec.CommonSpec, "webhook", resource.MustParse("1024Mi"))
@@ -114,13 +116,31 @@ func (e *extension) Reconcile(ctx context.Context, comp v1alpha1.KComponent) err
 			Type: "ConfigMap",
 		}
 	}
-	if err := monitoring.ReconcileServingMonitoring(ctx, e.kubeclient, ks); err != nil {
-		return err
+
+	// Explicitly set autocreateClusterDomainClaims to true if not otherwise set to be
+	// independent from upstream default changes.
+	common.ConfigureIfUnset(&ks.Spec.CommonSpec, "network", "autocreateClusterDomainClaims", "true")
+
+	// Temporary fix for SRVKS-743
+	if ks.Spec.Ingress.Istio.Enabled {
+		common.ConfigureIfUnset(&ks.Spec.CommonSpec, monitoring.ObservabilityCMName, monitoring.ObservabilityBackendKey, "none")
 	}
-	return nil
+	return monitoring.ReconcileMonitoringForServing(ctx, e.kubeclient, ks)
 }
 
-func (e *extension) Finalize(context.Context, v1alpha1.KComponent) error {
+func (e *extension) Finalize(ctx context.Context, comp v1alpha1.KComponent) error {
+	ks := comp.(*v1alpha1.KnativeServing)
+
+	// Delete the ingress namespaces manually. Manifestival won't do it for us in upgrade cases.
+	// See: https://github.com/manifestival/manifestival/issues/85
+	err := e.kubeclient.CoreV1().Namespaces().Delete(ctx, kourierNamespace(ks.GetNamespace()), metav1.DeleteOptions{})
+	if err != nil && !apierrors.IsNotFound(err) {
+		return fmt.Errorf("failed to remove ingress namespace: %w", err)
+	}
+
+	// Also default to Kourier here to pick the right manifest to uninstall.
+	defaultToKourier(ks)
+
 	return nil
 }
 
