@@ -6,7 +6,7 @@ import (
 	"github.com/openshift-knative/serverless-operator/test"
 )
 
-func TestKnativeControlPlaneMetrics(t *testing.T) {
+func TestKnativeMetrics(t *testing.T) {
 	caCtx := test.SetupClusterAdmin(t)
 	cleanup := func() {
 		test.CleanupAll(t, caCtx)
@@ -15,15 +15,22 @@ func TestKnativeControlPlaneMetrics(t *testing.T) {
 	defer cleanup()
 	t.Run("verify Serving control plane metrics work correctly", func(t *testing.T) {
 		// Serving control plane metrics should work
-		if err := VerifyControlPlaneMetrics(caCtx, servingMetricQueries); err != nil {
+		if err := VerifyMetrics(caCtx, servingMetricQueries); err != nil {
 			t.Fatal("Failed to verify that Serving control plane metrics work correctly", err)
 		}
 	})
 
 	t.Run("verify Eventing control plane metrics work correctly", func(t *testing.T) {
 		// Eventing control plane metrics should work
-		if err := VerifyControlPlaneMetrics(caCtx, eventingMetricQueries); err != nil {
+		if err := VerifyMetrics(caCtx, eventingMetricQueries); err != nil {
 			t.Fatal("Failed to verify that Eventing control plane metrics work correctly", err)
 		}
 	})
+
+	t.Run("verify Knative operators and Openshift ingress metrics work correctly", func(t *testing.T) {
+		// Knative operators and Openshift ingress metrics should work
+		if err := VerifyMetrics(caCtx, serverlessComponentQueries); err != nil {
+			t.Fatal("Failed to verify that Knative operators and Openshift ingress metrics work correctly", err)
+		}
+	})
 }
