@@ -26,7 +26,11 @@ fi
 # Run upgrade tests
 if [[ $TEST_KNATIVE_UPGRADE == true ]]; then
   install_serverless_previous
-  run_rolling_upgrade_tests "${UPGRADE_TEST_SCOPE:-serving,eventing}"
+  # Set KafkaChannel as default for upgrade tests.
+  if [[ $INSTALL_KAFKA == "true" ]]; then
+    ensure_kafka_channel_default
+  fi
+  run_rolling_upgrade_tests
   trigger_gc_and_print_knative
   # Call teardown only if E2E tests follow.
   if [[ $TEST_KNATIVE_E2E == true ]]; then
@@ -44,4 +48,6 @@ if [[ $TEST_KNATIVE_E2E == true ]]; then
   upstream_knative_eventing_e2e
 fi
 
+[ -n "$OPENSHIFT_CI" ] && check_serverless_alerts
+
 success
